@@ -1,9 +1,15 @@
 """prawcore: Low-level communication layer for PRAW 4+."""
 
 import logging
-from .auth import (Authorizer, DeviceIDAuthorizer, ReadOnlyAuthorizer,  # NOQA
-                   ImplicitAuthorizer, ScriptAuthorizer, TrustedAuthenticator,
-                   UntrustedAuthenticator)
+from .auth import (  # noqa
+    Authorizer,
+    DeviceIDAuthorizer,
+    ReadOnlyAuthorizer,
+    ImplicitAuthorizer,
+    ScriptAuthorizer,
+    TrustedAuthenticator,
+    UntrustedAuthenticator,
+)
 from .const import __version__  # noqa
 from .exceptions import *  # noqa
 from .requestor import Requestor  # noqa
