@@ -1,12 +1,5 @@
 """Provide exception classes for the prawcore package."""
-
-import sys
-
-
-if sys.version_info[0] == 2:
-    from urlparse import urlparse
-else:
-    from urllib.parse import urlparse
+from urllib.parse import urlparse
 
 
 class PrawcoreException(Exception):
@@ -31,8 +24,9 @@ class RequestException(PrawcoreException):
         self.original_exception = original_exception
         self.request_args = request_args
         self.request_kwargs = request_kwargs
-        super(RequestException, self).__init__('error with request {}'
-                                               .format(original_exception))
+        super(RequestException, self).__init__(
+            "error with request {}".format(original_exception)
+        )
 
 
 class ResponseException(PrawcoreException):
@@ -45,8 +39,9 @@ class ResponseException(PrawcoreException):
 
         """
         self.response = response
-        super(ResponseException, self).__init__('received {} HTTP response'
-                                                .format(response.status_code))
+        super(ResponseException, self).__init__(
+            "received {} HTTP response".format(response.status_code)
+        )
 
 
 class OAuthException(PrawcoreException):
@@ -63,9 +58,9 @@ class OAuthException(PrawcoreException):
         self.error = error
         self.description = description
         self.response = response
-        message = '{} error processing request'.format(error)
+        message = "{} error processing request".format(error)
         if description:
-            message += ' ({})'.format(description)
+            message += " ({})".format(description)
         PrawcoreException.__init__(self, message)
 
 
@@ -106,22 +101,50 @@ class Redirect(ResponseException):
     """
 
     def __init__(self, response):
-        """Initialize a Redirect exception instance..
+        """Initialize a Redirect exception instance.
 
         :param response: A requests.response instance containing a location
         header.
 
         """
-        path = urlparse(response.headers['location']).path
-        self.path = path[:-5] if path.endswith('.json') else path
+        path = urlparse(response.headers["location"]).path
+        self.path = path[:-5] if path.endswith(".json") else path
         self.response = response
-        PrawcoreException.__init__(self, 'Redirect to {}'.format(self.path))
+        msg = "Redirect to {}".format(self.path)
+        msg += (
+            " (You may be trying to perform a non-read-only action via a "
+            "read-only instance.)"
+            if "/login/" in self.path
+            else ""
+        )
+        PrawcoreException.__init__(self, msg)
 
 
 class ServerError(ResponseException):
     """Indicate issues on the server end preventing request fulfillment."""
 
 
+class SpecialError(ResponseException):
+    """Indicate syntax or spam-prevention issues."""
+
+    def __init__(self, response):
+        """Initialize a SpecialError exception instance.
+
+        :param response: A requests.response instance containing a message
+        and a list of special errors.
+
+        """
+        self.response = response
+
+        resp_dict = self.response.json()  # assumes valid JSON
+        self.message = resp_dict.get("message", "")
+        self.reason = resp_dict.get("reason", "")
+        self.special_errors = resp_dict.get("special_errors", [])
+        PrawcoreException.__init__(
+            self, "Special error {!r}".format(self.message)
+        )
+
+
 class TooLarge(ResponseException):
     """Indicate that the request data exceeds the allowed limit."""
 
