@@ -2,9 +2,11 @@
 from .exceptions import Forbidden, InsufficientScope, InvalidToken
 
 
-_auth_error_mapping = {403: Forbidden,
-                       'insufficient_scope': InsufficientScope,
-                       'invalid_token': InvalidToken}
+_auth_error_mapping = {
+    403: Forbidden,
+    "insufficient_scope": InsufficientScope,
+    "invalid_token": InvalidToken,
+}
 
 
 def authorization_error_class(response):
@@ -13,9 +15,9 @@ def authorization_error_class(response):
     :param response: The HTTP response containing a www-authenticate error.
 
     """
-    message = response.headers.get('www-authenticate')
+    message = response.headers.get("www-authenticate")
     if message:
-        error = message.replace('"', '').rsplit('=', 1)[1]
+        error = message.replace('"', "").rsplit("=", 1)[1]
     else:
         error = response.status_code
     return _auth_error_mapping[error](response)
